@@ -58,7 +58,7 @@ from .loader import load_url  # noqa
 from .manifest_provider.cache import CachedManifestProvider, CachedSourceManifestProvider  # noqa
 
 
-__version__ = '0.6.2'  # same version as in setup.py
+__version__ = '0.6.6'  # same version as in setup.py
 
 # index information
 
@@ -194,4 +194,5 @@ def _get_dist_file_data(index, dist_name, type_):
             data.append(_load_yaml_data(u))
     return data
 
-from .legacy import *
+
+from .legacy import *  # noqa
